@@ -14,36 +14,20 @@
 
 import unittest
 
-import mock
 from google.api_core import exceptions
 
-
-def _make_credentials():
-    import google.auth.credentials
-
-    return mock.Mock(spec=google.auth.credentials.Credentials)
+from ..helpers import make_connection, make_client as __make_client
 
 
 def _make_client(project="test-project", connection=None):
-    from google.cloud.bigquery.client import Client
-
+    client = __make_client(project)
     if connection is None:
-        connection = _make_connection()
+        connection = make_connection()
 
-    client = Client(project=project, credentials=_make_credentials(), _http=object())
     client._connection = connection
     return client
 
 
-def _make_connection(*responses):
-    import google.cloud.bigquery._http
-    from google.cloud.exceptions import NotFound
-
-    mock_conn = mock.create_autospec(google.cloud.bigquery._http.Connection)
-    mock_conn.api_request.side_effect = list(responses) + [NotFound("miss")]
-    return mock_conn
-
-
 def _make_retriable_exception():
     return exceptions.TooManyRequests(
         "retriable exception", errors=[{"reason": "rateLimitExceeded"}]
